<div class="row">
  <div class="col-lg-12">
    <nav class="my-4">
      {% if obj_list.has_other_pages %}
        <ul class="pagination pagination-circle pg-blue mb-0 float-right">
          {% if obj_list.has_previous %}
            <li class="page-item"><a class="page-link" aria-label="Previous" href="?page={{ obj_list.previous_page_number }}"><span aria-hidden="true">&laquo;</span><span class="sr-only">Previous</span></a></li>
          {% else %}
            <li class="page-item disabled"><span>&laquo;</span></li>
          {% endif %}
          {% for i in obj_list.paginator.page_range %}
            {% if obj_list.number == i %}
              <li class="page-item active"><span class="page-link">{{ i }} <span class="sr-only">(current)</span></span></li>
            {% else %}
              <li class="page-item"><a class="page-link" href="?page={{ i }}">{{ i }}</a></li>
            {% endif %}
          {% endfor %}
          {% if obj_list.has_next %}
            <li class="page-item"><a class="page-link" aria-label="Next" href="?page={{ obj_list.next_page_number }}"><span aria-hidden="true">&raquo;</span><span class="sr-only">Previous</span></a></li>
          {% else %}
            <li class="page-item disabled"><span>&raquo;</span></li>
          </li>
          {% endif %}
        </ul>
      {% endif %}
    </nav>
  </div>
</div>
